@@ -10,6 +10,7 @@
 #include "kosmindoormap_export.h"
 #include "mapcssproperty.h"
 #include "mapcsstypes.h"
+#include "mapcssexpression_p.h"
 
 #include <osm/datatypes.h>
 
@@ -27,8 +28,8 @@ class DataSet;
 class QIODevice;
 class PenWidthUtilTest;
 
-namespace KOSMIndoorMap { class MapCSSParserPrivate; }
-int yyparse(KOSMIndoorMap::MapCSSParserPrivate*, void*);
+namespace KOSMIndoorMap { class MapCSSParserContext; }
+int yyparse(KOSMIndoorMap::MapCSSParserContext*, void*);
 
 namespace KOSMIndoorMap {
 
@@ -108,13 +109,20 @@ public:
 
     ClassSelectorKey classSelectorKey() const;
 
-    void compile(const OSM::DataSet &dataSet);
+    /** Property is a valid eval() expression. */
+    [[nodiscard]] bool hasExpression() const;
+    /** Evaluate the expression in this declaration. */
+    [[nodiscard]] MapCSSValue evaluateExpression(const MapCSSExpressionContext &context) const;
+
+    void compile(OSM::DataSet &dataSet);
     void write(QIODevice *out) const;
 
+    [[nodiscard]] static MapCSSProperty propertyFromName(const char *name, std::size_t len);
+
 private:
-    friend int ::yyparse(KOSMIndoorMap::MapCSSParserPrivate*, void*);
+    friend int ::yyparse(KOSMIndoorMap::MapCSSParserContext*, void*);
     friend class ::PenWidthUtilTest;
-    friend class MapCSSParserPrivate;
+    friend class MapCSSParserContext;
 
     /** @internal, for use by the parser. */
     void setPropertyName(const char *name, std::size_t len);
@@ -137,6 +145,7 @@ private:
     QString m_stringValue;
     OSM::TagKey m_tagKey;
     ClassSelectorKey m_class;
+    MapCSSExpression m_evalExpression;
     Unit m_unit = NoUnit;
     Type m_type;
     bool m_boolValue = false;
